/*
 * Copyright Fastly, Inc.
 * Licensed under the MIT license. See LICENSE file for details.
 */
import commandLineArgs from 'command-line-args';
export function isHelpArgs(argv) {
    const helpDefinitions = [
        { name: 'help', type: Boolean, },
    ];
    const helpOptions = commandLineArgs(helpDefinitions, { argv, stopAtFirstUnknown: true });
    return !!helpOptions['help'];
}
export function findMainCommandNameAndArgs(argv) {
    const mainDefinitions = [
        { name: 'command', type: String, defaultOption: true },
    ];
    const mainOptions = commandLineArgs(mainDefinitions, { argv, stopAtFirstUnknown: true });
    const commandArgs = mainOptions._unknown || [];
    const command = mainOptions['command'];
    if (typeof command !== 'string') {
        return [null, commandArgs];
    }
    return [command, commandArgs];
}
export function getCommandAndArgs(argv, modes) {
    if (isHelpArgs(argv)) {
        return {
            needHelp: true,
            command: null,
        };
    }
    const result = findMainCommandNameAndArgs(argv);
    const [command, actionArgv] = result;
    if (command != null) {
        for (const modeName of modes) {
            if (command === modeName) {
                return {
                    needHelp: false,
                    command: command,
                    argv: actionArgv,
                };
            }
        }
    }
    try {
        commandLineArgs([], { argv: actionArgv });
    }
    catch (err) {
        console.log(String(err));
    }
    return {
        needHelp: true,
        command,
    };
}
